==> kubernetes-model-scheduling-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/scheduling/v1beta1/PriorityClassListBuilder.java <==
package io.fabric8.kubernetes.api.model.scheduling.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class PriorityClassListBuilder extends io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassListFluentImpl<io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassListBuilder> implements VisitableBuilder<io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassList,io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassListBuilder> {

    io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassListFluent<?> fluent;
    Boolean validationEnabled;

    public PriorityClassListBuilder() {
        this(true);
    }

    public PriorityClassListBuilder(Boolean validationEnabled) {
        this(new PriorityClassList(), validationEnabled);
    }

    public PriorityClassListBuilder(io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassListFluent<?> fluent) {
        this(fluent, true);
    }

    public PriorityClassListBuilder(io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassListFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new PriorityClassList(), validationEnabled);
    }

    public PriorityClassListBuilder(io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassListFluent<?> fluent,io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassList instance) {
        this(fluent, instance, true);
    }

    public PriorityClassListBuilder(io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassListFluent<?> fluent,io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassList instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public PriorityClassListBuilder(io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassList instance) {
        this(instance,true);
    }

    public PriorityClassListBuilder(io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassList instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassList build() {
        PriorityClassList buildable = new PriorityClassList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        PriorityClassListBuilder that = (PriorityClassListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-scheduling-5.3.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/scheduling/v1beta1/PriorityClassListBuilder.java <==
package io.fabric8.kubernetes.api.model.scheduling.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class PriorityClassListBuilder extends io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassListFluentImpl<io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassList,io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassListBuilder> {

    io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassListFluent<?> fluent;
    Boolean validationEnabled;

    public PriorityClassListBuilder() {
        this(true);
    }

    public PriorityClassListBuilder(Boolean validationEnabled) {
        this(new PriorityClassList(), validationEnabled);
    }

    public PriorityClassListBuilder(io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassListFluent<?> fluent) {
        this(fluent, true);
    }

    public PriorityClassListBuilder(io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassListFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new PriorityClassList(), validationEnabled);
    }

    public PriorityClassListBuilder(io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassListFluent<?> fluent,io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassList instance) {
        this(fluent, instance, true);
    }

    public PriorityClassListBuilder(io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassListFluent<?> fluent,io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassList instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public PriorityClassListBuilder(io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassList instance) {
        this(instance,true);
    }

    public PriorityClassListBuilder(io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassList instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.scheduling.v1beta1.PriorityClassList build() {
        PriorityClassList buildable = new PriorityClassList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        PriorityClassListBuilder that = (PriorityClassListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
